@@ -1,6 +1,6 @@
 from itertools import cycle
 import colorlover
-import dash_table
+from dash import dash_table
 import numpy as np
 import re
 
@@ -17,8 +17,8 @@ from covigator.dashboard.figures.figures import Figures, PLOTLY_CONFIG, TEMPLATE
 import plotly
 import plotly.express as px
 import plotly.graph_objects as go
-import dash_html_components as html
-import dash_core_components as dcc
+from dash import html
+from dash import dcc
 from covigator.database.model import Gene, Domain, DataSource
 
 VARIANT_TOOLTIP = '<b>%{text}</b><br>' + 'Allele frequency: %{y:.5f}<br>' + 'Genomic Position: %{x}'
@@ -134,6 +134,12 @@ class RecurrentMutationsFigures(Figures):
                     sort_by=[{"column_id": "frequency", "direction": "desc"}],
                     row_selectable='multi'
                 ),
+                html.Br(),
+                html.Div(children=[
+                    html.Button("Download CSV", id="btn_csv2"),
+                    dcc.Download(id="download-dataframe-csv2"),
+                    dcc.Store(id="memory2", data=data.to_dict('records'))]),
+                html.Br(),
                 dcc.Markdown("""
                     **Top occurring mutations table** 
                     *table shows the {} mutations{} with the highest frequency across all samples.*
@@ -184,7 +190,7 @@ class RecurrentMutationsFigures(Figures):
 
     def get_cooccurrence_heatmap(self, sparse_matrix, selected_variants, metric="jaccard", min_cooccurrences=5):
         data = self._get_variants_cooccurrence_matrix(data=sparse_matrix)
-        graph = dcc.Markdown("""**No co-occurrent mutations for the current selection**""")
+        graph = [dcc.Markdown("""**No co-occurrent mutations for the current selection**""")]
         if data is not None and data.shape[0] > 0:
 
             all_variants = data.variant_id_one.unique()
@@ -242,21 +248,21 @@ class RecurrentMutationsFigures(Figures):
 
             # the y index is reversed in plotly heatmap
             fig.update_yaxes(autorange="reversed")
-            graph = dcc.Graph(figure=fig, config=PLOTLY_CONFIG)
+            graph = [
+                dcc.Graph(figure=fig, config=PLOTLY_CONFIG),
+                dcc.Markdown("""
+                                    ***Co-occurrence matrix*** *showing variant pairs co-occurring in at least {} samples (this value is configurable).*
+                                    *The metric in the co-occurrence matrix can be chosen among counts, frequencies, Jaccard index or 
+                                    Cohen's kappa coefficient. The Cohen's kappa coefficient introduces a correction to the Jaccard index for
+                                    mutations with low occurrence.*
+                                    *The diagonal contains the total counts or just 1.0 in the other metrics.*
+                                    *The upper diagonal is not shown for clarity.*
+                                    *Synonymous mutations are excluded.*
+                                    *Different genomic mutations causing the same protein variant are not grouped.*
+                                    """.format(min_cooccurrences))
+            ]
 
-        return html.Div(children=[
-            graph,
-            dcc.Markdown("""
-                        ***Co-occurrence matrix*** *showing variant pairs co-occurring in at least {} samples (this value is configurable).*
-                        *The metric in the co-occurrence matrix can be chosen among counts, frequencies, Jaccard index or 
-                        Cohen's kappa coefficient. The Cohen's kappa coefficient introduces a correction to the Jaccard index for
-                        mutations with low occurrence.*
-                        *The diagonal contains the total counts or just 1.0 in the other metrics.*
-                        *The upper diagonal is not shown for clarity.*
-                        *Synonymous mutations are excluded.*
-                        *Different genomic mutations causing the same protein variant are not grouped.*
-                        """.format(min_cooccurrences))
-        ])
+        return html.Div(children=graph)
 
     def _get_variants_cooccurrence_matrix(self, data) -> pd.DataFrame:
         """
@@ -652,7 +658,7 @@ class RecurrentMutationsFigures(Figures):
 
     def get_variants_clustering(self, sparse_matrix, min_cooccurrence, min_samples):
 
-        data = self._get_mds(sparse_matrix=sparse_matrix, min_samples=min_samples)
+        data = self._run_clustering(sparse_matrix=sparse_matrix, min_samples=min_samples)
 
         tables = []
         if data is not None:
@@ -677,10 +683,12 @@ class RecurrentMutationsFigures(Figures):
                     sort_by=[{"column_id": "variant_id", "direction": "asc"}],
                 ))
                 tables.append(html.Br())
-
-        return html.Div(children=[
-            html.Div(children=tables),
-            dcc.Markdown("""
+            tables.append(html.Div(children=[
+                html.Button("Download CSV", id="btn_csv"),
+                dcc.Download(id="download-dataframe-csv"),
+                dcc.Store(id="memory", data=data.to_dict('records'))]))
+            tables.append(html.Br()),
+            tables.append(dcc.Markdown("""
             ***Co-occurrence clustering*** *shows the resulting clusters from the
             co-occurrence matrix with the Jaccard index corrected with the Cohen's kappa coefficient. 
             The co-occurrence matrix is built taking into account only mutations with at least {} pairwise 
@@ -692,9 +700,11 @@ class RecurrentMutationsFigures(Figures):
             *
 
             *Ankerst et al. “OPTICS: ordering points to identify the clustering structure.” ACM SIGMOD Record 28, no. 2 (1999): 49-60.*
-            """.format(min_cooccurrence, min_samples))])
+            """.format(min_cooccurrence, min_samples)))
 
-    def _get_mds(self, sparse_matrix, min_samples) -> pd.DataFrame:
+        return html.Div(children=tables)
+
+    def _run_clustering(self, sparse_matrix, min_samples) -> pd.DataFrame:
 
         data = None
 
