@@ -13,10 +13,6 @@ def get_footer():
                 dbc.Col([
                     html.Br(),
                     html.P("CoVigator {} © 2021 TRON. All Rights Reserved".format(covigator.VERSION)),
-                    html.P([
-                        "GISAID data provided on this website are subject to GISAID’s ",
-                        html.A("Terms and Conditions", href="https://www.gisaid.org/registration/terms-of-use/",
-                               target="_blank")]),
                     html.A(html.Img(src=tron_logo, id="tron-logo"), href="https://tron-mainz.de",  target="_blank"),
                     html.Br(),
                     dcc.Markdown("""
@@ -47,8 +43,8 @@ def get_footer():
                         "."
                         ]),
                     html.P([
-                        html.A("DATA PROTECTION", href="https://tron-mainz.de/data-protection/",  target="_blank"), " | ",
-                        html.A("IMPRINT", href="https://tron-mainz.de/imprint/",  target="_blank")])
+                        html.A("DATA PROTECTION", href="https://tron-mainz.de/data-protection",  target="_blank"), " | ",
+                        html.A("IMPRINT", href="https://tron-mainz.de/imprint",  target="_blank")])
                 ], style={"color": "#003c78", 'margin-left': '15px'})]
                 # this bit makes sure the footer sticks at the bottom
                 #style={"position": "relative", "bottom": "0", "width": "100%", "overflow": "hidden", "height": "120px"}
