@@ -3,18 +3,16 @@ import time
 import traceback
 import pandas as pd
 from contextlib import suppress
-from datetime import datetime
+from datetime import datetime, date
 from typing import Callable
 import typing as typing
 from dask.distributed import Client
 from distributed import fire_and_forget
 from logzero import logger
-import covigator
-import covigator.configuration
 from covigator.configuration import Configuration
 from covigator.database.database import Database, session_scope
-from covigator.database.model import Log, DataSource, CovigatorModule, JobStatus, SampleGisaid, \
-    SampleEna
+from covigator.database.model import Log, DataSource, CovigatorModule, JobStatus, \
+    SampleEna, LastUpdate
 from covigator.database.queries import Queries
 from covigator.exceptions import CovigatorExcludedSampleException, CovigatorErrorProcessingPangolinResults
 from covigator.precomputations.loader import PrecomputationsLoader
@@ -23,7 +21,7 @@ from covigator.precomputations.loader import PrecomputationsLoader
 class AbstractProcessor:
 
     def __init__(self, database: Database, dask_client: Client, data_source: DataSource, config: Configuration,
-                 download : bool = False, wait_time=60):
+                 wait_time=60):
         self.data_source = data_source
         self.config = config
         self.start_time = datetime.now()
@@ -36,7 +34,6 @@ class AbstractProcessor:
         self.session = self.database.get_database_session()
         self.queries = Queries(self.session)
         self.wait_time = wait_time
-        self.download = download
 
     def process(self):
         logger.info("Starting processor")
@@ -45,10 +42,7 @@ class AbstractProcessor:
         try:
             while True:
                 # queries 100 jobs every time to make sending to queue faster
-                jobs = self.queries.find_first_pending_jobs(
-                    self.data_source, n=1000,
-                    # only reads jobs in PENDING status if --download is indicated
-                    status=[JobStatus.PENDING, JobStatus.DOWNLOADED] if self.download else [JobStatus.DOWNLOADED])
+                jobs = self.queries.find_first_pending_jobs(self.data_source, n=1000, status=[JobStatus.DOWNLOADED])
                 if jobs is None or len(jobs) == 0:
                     logger.info("No more jobs to process after sending {} runs to process".format(count))
                     break
@@ -80,6 +74,9 @@ class AbstractProcessor:
             # precomputes data right after processor
             PrecomputationsLoader(session=self.session).load()
 
+            # updates the last update entry
+            self._register_last_update()
+
         except Exception as e:
             logger.exception(e)
             self.session.rollback()
@@ -96,6 +93,11 @@ class AbstractProcessor:
                 self.session.close()
             logger.info("Cluster and database sessions closed")
 
+    def _register_last_update(self):
+        last_update = LastUpdate(source=self.data_source, update_time=date.today())
+        self.session.add(last_update)
+        self.session.commit()
+
     def _wait_for_batch(self):
         logger.info("Waiting for a batch of jobs...")
         while (count_pending_jobs := self.queries.count_jobs_in_queue(data_source=self.data_source)) > 0:
@@ -106,13 +108,12 @@ class AbstractProcessor:
     @staticmethod
     def run_job(config: Configuration, run_accession: str, start_status: JobStatus, end_status: JobStatus,
                 error_status: JobStatus, data_source: DataSource,
-                function: Callable[[typing.Union[SampleEna, SampleGisaid] , Queries, Configuration],
-                                   typing.Union[SampleEna, SampleGisaid]]) -> str or None:
+                function: Callable[[typing.Union[SampleEna], Queries, Configuration],
+                                   typing.Union[SampleEna]]) -> str or None:
         """
         Runs a function on a job, if anything goes wrong or does not fit in the DB it returns None in order to
         stop the execution of subsequent jobs.
         """
-        covigator.configuration.initialise_logs(config.logfile_processor, sample_id=run_accession)
         if run_accession is not None:
             try:
                 with session_scope(config=config) as session:
@@ -124,7 +125,6 @@ class AbstractProcessor:
                         if end_status is not None:
                             sample.status = end_status
                     else:
-                        logger.warning("Expected ENA job {} in status {}".format(run_accession, start_status))
                         run_accession = None
             except CovigatorExcludedSampleException as e:
                 # captures exclusion cases
@@ -139,8 +139,6 @@ class AbstractProcessor:
                         config=config, run_accession=run_accession, exception=e, status=error_status,
                         data_source=data_source)
                     run_accession = None
-                else:
-                    logger.warning("Error processing a job that does not stop the workflow!")
         return run_accession
 
     @abc.abstractmethod
@@ -170,15 +168,13 @@ class AbstractProcessor:
     @staticmethod
     def _log_error_in_job(config: Configuration, run_accession: str, exception: Exception, status: JobStatus, data_source: DataSource):
         with session_scope(config=config) as session:
-            logger.exception(exception)
-            logger.info("Error on job {} on state {}: {}".format(run_accession, status, str(exception)))
             sample = Queries(session).find_job_by_accession(run_accession=run_accession, data_source=data_source)
             sample.status = status
             sample.failed_at = datetime.now()
             sample.error_message = AbstractProcessor._get_traceback_from_exception(exception)
 
     @staticmethod
-    def load_pangolin(sample: typing.Union[SampleGisaid, SampleEna], path: str) -> typing.Union[SampleGisaid, SampleEna]:
+    def load_pangolin(sample: typing.Union[SampleEna], path: str) -> typing.Union[SampleEna]:
         try:
             data = pd.read_csv(path,
                                na_values=None,
@@ -191,9 +187,10 @@ class AbstractProcessor:
                                    'scorpio_conflict': float,
                                    'version': str,
                                    'pangolin_version': str,
-                                   'pangoLEARN_version': str,
-                                   'pango_version': str,
-                                   'status': str,
+                                   'scorpio_version': str,
+                                   'constellation_version': str,
+                                   'qc_status': str,
+                                   'qc_notes': str,
                                    'note': str
                                })
 
@@ -203,8 +200,8 @@ class AbstractProcessor:
             data.scorpio_call.fillna(value="", inplace=True)
             data.version.fillna(value="", inplace=True)
             data.pangolin_version.fillna(value="", inplace=True)
-            data.pangoLEARN_version.fillna(value="", inplace=True)
-            data.pango_version.fillna(value="", inplace=True)
+            data.scorpio_version.fillna(value="", inplace=True)
+            data.constellation_version.fillna(value="", inplace=True)
             data.note.fillna(value="", inplace=True)
             data.conflict.fillna(value=0.0, inplace=True)
             data.ambiguity_score.fillna(value=0.0, inplace=True)
@@ -219,9 +216,10 @@ class AbstractProcessor:
             sample.pangolin_scorpio_conflict = data.scorpio_conflict.loc[0]
             sample.pangolin_version = data.version.loc[0]
             sample.pangolin_pangolin_version = data.pangolin_version.loc[0]
-            sample.pangolin_pangoLEARN_version = data.pangoLEARN_version.loc[0]
-            sample.pangolin_pango_version = data.pango_version.loc[0]
-            sample.pangolin_status = data.status.loc[0]
+            sample.pangolin_scorpio_version = data.scorpio_version.loc[0]
+            sample.pangolin_constellation_version = data.constellation_version.loc[0]
+            sample.pangolin_qc_status = data.qc_status.loc[0]
+            sample.pangolin_qc_notes = data.qc_notes.loc[0]
             sample.pangolin_note = data.note.loc[0]
         except Exception as e:
             raise CovigatorErrorProcessingPangolinResults(e)
