@@ -2,7 +2,7 @@ import unittest
 
 from covigator.configuration import Configuration
 from covigator.pipeline.ena_pipeline import Pipeline
-from covigator.pipeline.gisaid_pipeline import GisaidPipeline
+
 
 class PipelineTest(unittest.TestCase):
 
@@ -21,15 +21,5 @@ class PipelineTest(unittest.TestCase):
         self.assertEqual(open(vcf).read(), open(vcf_file).read())
 
 
-class GisaidPipelineTest(unittest.TestCase):
-    
-    def test_pipeline_run(self):
-        run_accession = "EPI_ISL_417140"
-        vcf_file = "gisaid.vcf"
-
-        p = GisaidPipeline(config=Configuration())
-
-        self.assertEqual(open(p.run(run_accession=run_accession)).read(), open(vcf_file).read())
-
 if __name__ == '__main__':
     unittest.main()
