@@ -3,11 +3,10 @@ from faker import Faker
 from logzero import logger
 from covigator.database.database import Database
 from covigator.database.model import VariantCooccurrence, SampleEna, VariantObservation, \
-    SampleGisaid, SubclonalVariantObservation, Variant, PrecomputedVariantAbundanceHistogram, PrecomputedTableCounts, \
+    SubclonalVariantObservation, Variant, PrecomputedVariantAbundanceHistogram, PrecomputedTableCounts, \
     PrecomputedSynonymousNonSynonymousCounts, PrecomputedOccurrence, PrecomputedAnnotation, PrecomputedIndelLength, \
-    PrecomputedSubstitutionsCounts, PrecomputedVariantsPerSample, Log, GisaidVariant, GisaidVariantObservation, \
-    LowFrequencyVariantObservation, LowFrequencyVariant, SubclonalVariant, PrecomputedVariantsPerLineage, \
-    GisaidVariantCooccurrence
+    PrecomputedSubstitutionsCounts, PrecomputedVariantsPerSample, Log, \
+    LowFrequencyVariantObservation, LowFrequencyVariant, SubclonalVariant, PrecomputedVariantsPerLineage
 from covigator.database.queries import Queries
 from covigator.tests.unit_tests.faked_objects import FakeConfiguration
 
@@ -41,18 +40,14 @@ class AbstractTest(TestCase):
 
     def _clean_test_database(self):
         try:
-            self._clean_table(GisaidVariantObservation)
             self._clean_table(VariantObservation)
             self._clean_table(SubclonalVariantObservation)
             self._clean_table(LowFrequencyVariantObservation)
             self._clean_table(SampleEna)
-            self._clean_table(SampleGisaid)
             self._clean_table(VariantCooccurrence)
-            self._clean_table(GisaidVariantCooccurrence)
             self._clean_table(Variant)
             self._clean_table(SubclonalVariant)
             self._clean_table(LowFrequencyVariant)
-            self._clean_table(GisaidVariant)
             self._clean_table(PrecomputedVariantsPerSample)
             self._clean_table(PrecomputedSubstitutionsCounts)
             self._clean_table(PrecomputedIndelLength)
