@@ -11,7 +11,7 @@ class DownloaderTest(AbstractTest):
     def setUp(self) -> None:
         self.downloader = Downloader(config=self.config)
 
-    @unittest.skip
+    #@unittest.skip
     def test_download_ena_run_with_bad_md5(self):
         run_accession = "TEST12345"
         ena_run = SampleEna(
